class PointsController < ApplicationController
  before_action :set_point, only: [:show, :edit, :update, :destroy]
  caches_page :index, :list

  def index
    @points = Point.includes(:neighbour).references(:neighbour)
    @points = @points.select{ |pt| pt.tags['CITYDISTRICT'] =~ /#{params[:citydistrict]}/ } if params[:citydistrict]

    cookies[:lat] ||= 50.0950
    cookies[:lon] ||= 14.3611
    @mappos = [cookies[:lat],cookies[:lon]]

    @markers = @points.first(2).map do |point|
      ladim_popupy = false # tohle je treba dat true pokazde kdyz ladim popupy
      if point.cache_popup.nil? or ladim_popupy
        point.cache_popup = render_to_string partial: "#{point.typ}_popup", locals: {point: point}, layout: false
        if point.has_neighbour?
          point.cache_popup += "<hr>Spárováno s bodem:"
          point.cache_popup += render_to_string partial: "#{point.neighbour.typ}_popup", locals: {point: point.neighbour}, layout: false
        end
        point.save
      end
  
    { latlng: point.location, icon: point.icon_options, popup: point.cache_popup }
    end
    respond_to do |format|
      format.html
      format.json
    end
		
  end

  def list
    @points = Point.all
  end

  def test
    render layout: false
  end

  # GET /points/1
  # GET /points/1.json
  def show
  end

  # GET /points/new
  def new
    @point = Point.new
  end

  # GET /points/1/edit
  def edit
  end

  def create
    @point = Point.new(point_params)

    respond_to do |format|
      if @point.save
        format.html { redirect_to @point, notice: 'Point was successfully created.' }
        format.json { render :show, status: :created, location: @point }
      else
        format.html { render :new }
        format.json { render json: @point.errors, status: :unprocessable_entity }
      end
    end
  end

  def update
    respond_to do |format|
      if @point.update(point_params)
        format.html { redirect_to @point, notice: 'Point was successfully updated.' }
        format.json { render :show, status: :ok, location: @point }
      else
        format.html { render :edit }
        format.json { render json: @point.errors, status: :unprocessable_entity }
      end
    end
  end

  def destroy
    @point.destroy
    respond_to do |format|
      format.html { redirect_to points_url, notice: 'Point was successfully destroyed.' }
      format.json { head :no_content }
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_point
      @point = Point.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def point_params
      params.require(:point).permit(:lat,:lon)
    end
end
